@@ -61,6 +61,27 @@ typedef gboolean (*GstRTSPClientSendFunc)      (GstRTSPClient *client,
                                                 gboolean close,
                                                 gpointer user_data);
 
+/**
+ * GstRTSPClientSendMessagesFunc:
+ * @client: a #GstRTSPClient
+ * @messages: #GstRTSPMessage
+ * @n_messages: number of messages
+ * @close: close the connection
+ * @user_data: user data when registering the callback
+ *
+ * This callback is called when @client wants to send @messages. When @close is
+ * %TRUE, the connection should be closed when the message has been sent.
+ *
+ * Returns: %TRUE on success.
+ *
+ * Since: 1.16
+ */
+typedef gboolean (*GstRTSPClientSendMessagesFunc)      (GstRTSPClient *client,
+                                                        GstRTSPMessage *messages,
+                                                        guint n_messages,
+                                                        gboolean close,
+                                                        gpointer user_data);
+
 /**
  * GstRTSPClient:
  *
@@ -87,7 +108,7 @@ struct _GstRTSPClient {
  * @params_get: get parameters. This function should also initialize the
  *    RTSP response(ctx->response) via a call to gst_rtsp_message_init_response()
  * @tunnel_http_response: called when a response to the GET request is about to
- *   be sent for a tunneled connection. The response can be modified. Since: 1.4
+ *   be sent for a tunneled connection. The response can be modified. Since 1.4
  *
  * The client class structure.
  */
@@ -195,6 +216,12 @@ void                  gst_rtsp_client_set_send_func     (GstRTSPClient *client,
                                                          gpointer user_data,
                                                          GDestroyNotify notify);
 
+GST_RTSP_SERVER_API
+void                  gst_rtsp_client_set_send_messages_func (GstRTSPClient *client,
+                                                              GstRTSPClientSendMessagesFunc func,
+                                                              gpointer user_data,
+                                                              GDestroyNotify notify);
+
 GST_RTSP_SERVER_API
 GstRTSPResult         gst_rtsp_client_handle_message    (GstRTSPClient *client,
                                                          GstRTSPMessage *message);
